## 任务类型(Task Type)
故障根因诊断。



## 任务描述(Task Description)

根据事件识别输出的事件信息和初步定界分析、初步根因分析、初步影响分析等信息，进行故障事件的根因定位，输出根因定位信息及建议处理方案。



## 任务目标(Task Target)

{{任务目标}}（必选）

要求：说明对故障诊断任务的具体要求，如完成故障事件的根因定位，输出专业根因定位信息、故障根因专业分类、故障根因详情、远程处置方案、现场抢修方案及业务影响分析。

样例：请进行故障事件的根因定位，输出专业根因定位信息、故障根因专业分类、故障根因详情、远程处置方案、现场抢修方案及业务影响分析。



## 任务上下文(Task Context)

{{任务上下文}}（必选）

要求：故障根因诊断任务可包含多条告警事件，每条事件可包含以下信息：

1. 故障事件流水号，必选。样例：1856365516_2839324485_2130908106_4130674041
2. 事件标题名称，必选。样例：5G基站退服事件
3. 事件关联的告警厂家内部流水号，必选。样例：123211121244
4. 事件关联的传输专业告警扩展流水号，可选。
5. 事件关联告警在网管系统内唯一标识，必选。样例：0108-007-012-10-000003
6. 事件关联告警标题，必选。样例：gNodeB退服告警
7. 事件产生时间，必选。样例：2025-05-22 08:40:44
8. 告警级别，数字越小越严重。一级告警（Critical）；二级告警（Major）；三级告警（Minor）；四级告警（Warning）。必选。样例：四级告警
9. 基站ID，无线工作台用。可选。样例：2148660
10. 网元名称，必选。样例：泉州惠安-惠安张坂玉山灯杆G-HRHH
11. 电路号，可选。样例：泉州惠安张坂惠南联兴-泉州惠安局楼10GE1097086NR
12. 机房信息，可选。样例：泉州惠安张坂玉山一楼自建机房

样例：有1条待诊断的告警事件，具体内容如下：

- 事件流水号是1856365516_2839324485_2130908106_4130674041，标题为5G基站退服事件，事件关联的告警厂家内部流水号为123211121244，事件关联告警在网管系统内唯一标识为0108-007-012-10-000003，事件关联告警标题是gNodeB退服告警，事件产生时间为2025-05-22 08:40:44，告警级别是四级，网元名称为泉州惠安-惠安张坂玉山灯杆G-HRHH。

  

## 预期输出(Expected Output)
{{预期输出}}（可选）

要求：针对预期返回的故障诊断结果，需要声明如下信息：

1. 需要声明基于A2A的哪一类Part承载，如DataPart或TextPart。
2. 需要声明包含哪些信息要素（如诊断结果、定位结论、定位分析过程等）

样例：要求通过TextPart返回故障诊断结果。故障诊断结果的具体内容要求如下： 

1. 故障根因定位结果的取值范围包括：成功、驳回、失败、其他。
2. 故障根因详细信息，包括 故障根因的名称、详情、修复建议（含远程处理和现场抢修）、定位分析过程、业务影响， 故障根因点所在资源对象的标识、类型，名称，详细位置等信息。  
